@@ -1988,17 +1988,6 @@ static inline void nv_mutex_destroy(struct mutex *lock)
 
 }
 
-#if LINUX_VERSION_CODE < KERNEL_VERSION(6, 3, 0)
-// Rel. commit "mm: introduce vma->vm_flags wrapper functions" (Suren Baghdasaryan, 26 Jan 2023)
-static inline void vm_flags_set(struct vm_area_struct *vma, vm_flags_t flags)
-{
-    vma->vm_flags |= flags;
-}
-
-static inline void vm_flags_clear(struct vm_area_struct *vma, vm_flags_t flags)
-{
-    vma->vm_flags &= ~flags;
-}
-#endif
-
+#define NV_CHECK_EXPORT_SYMBOL(symbol)  (NV_IS_EXPORT_SYMBOL_PRESENT_##symbol && \
+                                         !NV_IS_EXPORT_SYMBOL_GPL_##symbol)
 #endif  /* _NV_LINUX_H_ */
